@@ -364,7 +364,7 @@ QVariantList Backend::recentDocumentActions(const QUrl &launcherUrl, QObject *pa
         storageId = storageId.left(storageId.length() - 8);
     }
 
-    auto query = UsedResources | RecentlyUsedFirst | Agent(storageId) | Type::any() | Activity::current() | Url::file();
+    auto query = UsedResources | RecentlyUsedFirst | Agent(storageId) | Type::files() | Activity::current() | Url::file();
 
     ResultSet results(query);
 
@@ -383,11 +383,7 @@ QVariantList Backend::recentDocumentActions(const QUrl &launcherUrl, QObject *pa
             continue;
         }
 
-        const KFileItem fileItem(url);
-
-        if (!fileItem.isFile()) {
-            continue;
-        }
+        const KFileItem fileItem(url, KFileItem::SkipMimeTypeFromContent);
 
         QAction *action = new QAction(parent);
         action->setText(url.fileName());
@@ -608,7 +604,8 @@ void Backend::windowsHovered(const QVariant &_winIds, bool hovered)
         m_windowsToHighlight = _winIds.toStringList();
     }
 
-    updateWindowHighlight();
+    // Avoid flickering when scrolling in the tooltip
+    QTimer::singleShot(0, this, &Backend::updateWindowHighlight);
 }
 
 void Backend::updateWindowHighlight()
