@@ -74,6 +74,7 @@ class FOLDERPLUGIN_TESTS_EXPORT FolderModel : public QSortFilterProxyModel, publ
     Q_PROPERTY(Status status READ status NOTIFY statusChanged)
     Q_PROPERTY(QString errorString READ errorString NOTIFY errorStringChanged)
     Q_PROPERTY(bool dragging READ dragging NOTIFY draggingChanged)
+    Q_PROPERTY(bool dragInProgressAnywhere READ isDragInProgressAnywhere NOTIFY dragInProgressAnywhereChanged)
     Q_PROPERTY(bool usedByContainment READ usedByContainment WRITE setUsedByContainment NOTIFY usedByContainmentChanged)
     Q_PROPERTY(bool locked READ locked WRITE setLocked NOTIFY lockedChanged)
     Q_PROPERTY(int sortMode READ sortMode WRITE setSortMode NOTIFY sortModeChanged)
@@ -140,6 +141,7 @@ public:
     QString errorString() const;
 
     bool dragging() const;
+    bool isDragInProgressAnywhere() const;
 
     bool usedByContainment() const;
     void setUsedByContainment(bool used);
@@ -248,6 +250,7 @@ Q_SIGNALS:
     void statusChanged() const;
     void errorStringChanged() const;
     void draggingChanged() const;
+    void dragInProgressAnywhereChanged() const;
     void usedByContainmentChanged() const;
     void lockedChanged() const;
     void sortModeChanged() const;
@@ -265,6 +268,7 @@ Q_SIGNALS:
     void requestRename() const;
     void move(int x, int y, QList<QUrl> urls);
     void popupMenuAboutToShow(KIO::DropJob *dropJob, QMimeData *mimeData, int x, int y);
+    void selectionChanged() const;
 
 protected:
     bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const override;
@@ -276,7 +280,7 @@ private Q_SLOTS:
     void dirListFailed(const QString &error);
     void statResult(KJob *job);
     void evictFromIsDirCache(const KFileItemList &items);
-    void selectionChanged(const QItemSelection &selected, const QItemSelection &deselected);
+    void changeSelection(const QItemSelection &selected, const QItemSelection &deselected);
     void pasteTo();
     void moveSelectedToTrash();
     void emptyTrashBin();
@@ -312,7 +316,6 @@ private:
     QModelIndexList m_dragIndexes;
     QHash<int, DragImage *> m_dragImages;
     QPoint m_dragHotSpotScrollOffset;
-    bool m_dragInProgress;
     bool m_urlChangedWhileDragging;
     // target filename to target position of a drop event, note that this deliberately
     // is not using the URL to easily support desktop:/ URL schemes
@@ -351,4 +354,26 @@ private:
     QPoint m_menuPosition;
 };
 
+class DragTracker : public QObject
+{
+    Q_OBJECT
+public:
+    DragTracker(QObject *parent = nullptr);
+    ~DragTracker();
+
+    bool isDragInProgress() const;
+    void setDragInProgress(FolderModel *dragOwner, bool drag);
+
+    FolderModel *dragOwner();
+
+    static DragTracker *self();
+
+Q_SIGNALS:
+    void dragInProgressChanged(bool dragInProgress);
+
+private:
+    bool m_dragInProgress = false;
+    QPointer<FolderModel> m_dragOwner;
+};
+
 #endif
