@@ -29,7 +29,12 @@ MimeTypesModel::~MimeTypesModel()
 
 QHash<int, QByteArray> MimeTypesModel::roleNames() const
 {
-    return {{Qt::DisplayRole, "comment"}, {Qt::UserRole, "name"}, {Qt::DecorationRole, "decoration"}, {Qt::CheckStateRole, "checked"}};
+    return {
+        {Qt::DisplayRole, "comment"},
+        {Qt::UserRole, "name"},
+        {Qt::DecorationRole, "decoration"},
+        {Qt::CheckStateRole, "checked"},
+    };
 }
 
 QVariant MimeTypesModel::data(const QModelIndex &index, int role) const
@@ -111,7 +116,7 @@ void MimeTypesModel::setCheckedTypes(const QStringList &list)
 {
     m_checkedRows = QVector<bool>(m_mimeTypesList.size(), false);
 
-    foreach (const QString &name, list) {
+    for (const QString &name : list) {
         const int row = indexOfType(name);
 
         if (row != -1) {
