@@ -48,7 +48,7 @@ ViewPropertiesMenu::ViewPropertiesMenu(QObject *parent)
     m_iconSizeMenu = m_menu->addMenu(QIcon::fromTheme(QStringLiteral("transform-scale")), i18n("Icon Size"));
     m_iconSize = new QActionGroup(this);
     connect(m_iconSize, &QActionGroup::triggered, this, &ViewPropertiesMenu::iconSizeChanged);
-    const QStringList iconSizes{i18n("Tiny"), i18n("Small"), i18n("Small Medium"), i18n("Medium"), i18n("Large"), i18n("Huge")};
+    const QStringList iconSizes{i18n("Tiny"), i18n("Very Small"), i18n("Small"), i18n("Small-Medium"), i18n("Medium"), i18n("Large"), i18n("Huge")};
     for (int i = 0; i < iconSizes.count(); ++i) {
         action = m_iconSizeMenu->addAction(iconSizes.at(i));
         action->setCheckable(true);
@@ -147,7 +147,8 @@ int ViewPropertiesMenu::arrangement() const
 void ViewPropertiesMenu::setArrangement(int arrangement)
 {
     if (!m_arrangement->checkedAction() || m_arrangement->checkedAction()->data().toInt() != arrangement) {
-        foreach (QAction *action, m_arrangement->actions()) {
+        const QList<QAction *> actions = m_arrangement->actions();
+        for (QAction *action : actions) {
             if (action->data().toInt() == arrangement) {
                 action->setChecked(true);
                 break;
@@ -164,7 +165,8 @@ int ViewPropertiesMenu::alignment() const
 void ViewPropertiesMenu::setAlignment(int alignment)
 {
     if (!m_alignment->checkedAction() || m_alignment->checkedAction()->data().toInt() != alignment) {
-        foreach (QAction *action, m_alignment->actions()) {
+        const QList<QAction *> actions = m_alignment->actions();
+        for (QAction *action : actions) {
             if (action->data().toInt() == alignment) {
                 action->setChecked(true);
                 break;
@@ -218,7 +220,8 @@ int ViewPropertiesMenu::sortMode() const
 void ViewPropertiesMenu::setSortMode(int sortMode)
 {
     if (!m_sortMode->checkedAction() || m_sortMode->checkedAction()->data().toInt() != sortMode) {
-        foreach (QAction *action, m_sortMode->actions()) {
+        const QList<QAction *> actions = m_sortMode->actions();
+        for (QAction *action : actions) {
             if (action->data().toInt() == sortMode) {
                 action->setChecked(true);
                 break;
