@@ -1,23 +1,10 @@
-/***************************************************************************
- *   Copyright (C) 2002 Joseph Wenninger <jowenn@kde.org>                  *
- *   Copyright (C) 2020 Méven Car <meven.car@kdemail.net>                  *
- *   Copyright (C) 2020 Tobias Fella <fella@posteo.de>                     *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2002 Joseph Wenninger <jowenn@kde.org>
+    SPDX-FileCopyrightText: 2020 Méven Car <meven.car@kdemail.net>
+    SPDX-FileCopyrightText: 2020 Tobias Fella <fella@posteo.de>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "componentchooserterminal.h"
 
@@ -84,7 +71,7 @@ void ComponentChooserTerminal::load()
         m_index = m_applications.length() - 1;
     }
     QVariantMap application;
-    application["name"] = i18n("Other...");
+    application["name"] = i18n("Other…");
     application["icon"] = QStringLiteral("application-x-shellscript");
     application["storageId"] = QLatin1String("");
     m_applications += application;
