@@ -20,6 +20,8 @@ class KcmComponentChooser : public KQuickAddons::ManagedConfigModule
     Q_PROPERTY(ComponentChooser *emailClients READ emailClients CONSTANT)
     Q_PROPERTY(ComponentChooser *terminalEmulators READ terminalEmulators CONSTANT)
     Q_PROPERTY(ComponentChooser *fileManagers READ fileManagers CONSTANT)
+    Q_PROPERTY(ComponentChooser *geoUriHandlers READ geoUriHandlers CONSTANT)
+    Q_PROPERTY(ComponentChooser *telUriHandlers READ telUriHandlers CONSTANT)
 
 public:
     KcmComponentChooser(QObject *parent, const QVariantList &args);
@@ -28,6 +30,8 @@ public:
     ComponentChooser *emailClients() const;
     ComponentChooser *terminalEmulators() const;
     ComponentChooser *fileManagers() const;
+    ComponentChooser *geoUriHandlers() const;
+    ComponentChooser *telUriHandlers() const;
 
     void defaults() override;
     void load() override;
@@ -36,7 +40,7 @@ public:
     bool isSaveNeeded() const override;
 
 private:
-    ComponentChooserData *m_data;
+    ComponentChooserData *const m_data;
 };
 
 #endif
