@@ -40,7 +40,7 @@ private Q_SLOTS:
 
     void testModel()
     {
-        foreach (const ModelInfo *modelInfo, rules->modelInfos) {
+        for (const ModelInfo *modelInfo : std::as_const(rules->modelInfos)) {
             QVERIFY(modelInfo != nullptr);
             QVERIFY(modelInfo->name.length() > 0);
             QVERIFY(modelInfo->description.length() > 0);
@@ -50,19 +50,19 @@ private Q_SLOTS:
 
     void testLayouts()
     {
-        foreach (const LayoutInfo *layoutInfo, rules->layoutInfos) {
+        for (const LayoutInfo *layoutInfo : std::as_const(rules->layoutInfos)) {
             QVERIFY(layoutInfo != nullptr);
             QVERIFY(!layoutInfo->name.isEmpty());
             //        	const char* desc = layoutInfo->name.toUtf8() ;
             //        	qDebug() << layoutInfo->name;
             QVERIFY(!layoutInfo->description.isEmpty());
 
-            foreach (const VariantInfo *variantInfo, layoutInfo->variantInfos) {
+            for (const VariantInfo *variantInfo : layoutInfo->variantInfos) {
                 QVERIFY(variantInfo != nullptr);
                 QVERIFY(!variantInfo->name.isEmpty());
                 QVERIFY(!variantInfo->description.isEmpty());
             }
-            foreach (const QString &language, layoutInfo->languages) {
+            for (const QString &language : layoutInfo->languages) {
                 QVERIFY(!language.isEmpty());
             }
         }
@@ -70,13 +70,13 @@ private Q_SLOTS:
 
     void testOptionGroups()
     {
-        foreach (const OptionGroupInfo *optionGroupInfo, rules->optionGroupInfos) {
+        for (const OptionGroupInfo *optionGroupInfo : std::as_const(rules->optionGroupInfos)) {
             QVERIFY(optionGroupInfo != nullptr);
             QVERIFY(!optionGroupInfo->name.isEmpty());
             QVERIFY(!optionGroupInfo->description.isEmpty());
             // optionGroupInfo->exclusive
 
-            foreach (const OptionInfo *optionInfo, optionGroupInfo->optionInfos) {
+            for (const OptionInfo *optionInfo : optionGroupInfo->optionInfos) {
                 QVERIFY(optionInfo != nullptr);
                 QVERIFY(!optionInfo->name.isEmpty());
                 QVERIFY(!optionInfo->description.isEmpty());
@@ -86,15 +86,15 @@ private Q_SLOTS:
 
     void testExtras()
     {
-        Rules *rulesWithExtras = Rules::readRules(Rules::READ_EXTRAS);
+        const Rules *rulesWithExtras = Rules::readRules(Rules::READ_EXTRAS);
         QVERIFY2(rulesWithExtras->layoutInfos.size() > rules->layoutInfos.size(), "Rules with extras should have more layouts");
 
-        foreach (const LayoutInfo *layoutInfo, rules->layoutInfos) {
+        for (const LayoutInfo *layoutInfo : std::as_const(rules->layoutInfos)) {
             QVERIFY(!layoutInfo->fromExtras);
         }
 
         bool foundFromExtras = false, foundNonExtras = false;
-        foreach (const LayoutInfo *layoutInfo, rulesWithExtras->layoutInfos) {
+        for (const LayoutInfo *layoutInfo : rulesWithExtras->layoutInfos) {
             if (layoutInfo->fromExtras)
                 foundFromExtras = true;
             if (!layoutInfo->fromExtras)
@@ -115,7 +115,7 @@ private Q_SLOTS:
 
         QDomElement modelList = doc.createElement(QStringLiteral("modelList"));
         root.appendChild(modelList);
-        foreach (const ModelInfo *modelInfo, rules->modelInfos) {
+        for (const ModelInfo *modelInfo : std::as_const(rules->modelInfos)) {
             QDomElement model = doc.createElement(QStringLiteral("model"));
             model.setAttribute(QStringLiteral("name"), modelInfo->name);
             model.setAttribute(QStringLiteral("description"), modelInfo->description);
@@ -124,13 +124,13 @@ private Q_SLOTS:
         }
 
         QDomElement layoutList = doc.createElement(QStringLiteral("layoutList"));
-        foreach (const LayoutInfo *layoutInfo, rules->layoutInfos) {
+        for (const LayoutInfo *layoutInfo : std::as_const(rules->layoutInfos)) {
             QDomElement layout = doc.createElement(QStringLiteral("layout"));
             layout.setAttribute(QStringLiteral("name"), layoutInfo->name);
             layout.setAttribute(QStringLiteral("description"), layoutInfo->description);
 
             QDomElement langList = doc.createElement(QStringLiteral("languageList"));
-            foreach (const QString &lang, layoutInfo->languages) {
+            for (const QString &lang : layoutInfo->languages) {
                 QDomElement langNode = doc.createElement(QStringLiteral("lang"));
                 langNode.setAttribute(QStringLiteral("iso639Id"), lang);
                 langList.appendChild(langNode);
@@ -140,13 +140,13 @@ private Q_SLOTS:
             }
 
             QDomElement variantList = doc.createElement(QStringLiteral("variantList"));
-            foreach (const VariantInfo *variantInfo, layoutInfo->variantInfos) {
+            for (const VariantInfo *variantInfo : layoutInfo->variantInfos) {
                 QDomElement variant = doc.createElement(QStringLiteral("variant"));
                 variant.setAttribute(QStringLiteral("name"), variantInfo->name);
                 variant.setAttribute(QStringLiteral("description"), variantInfo->description);
 
                 QDomElement langList = doc.createElement(QStringLiteral("languageList"));
-                foreach (const QString &lang, variantInfo->languages) {
+                for (const QString &lang : variantInfo->languages) {
                     QDomElement langNode = doc.createElement(QStringLiteral("lang"));
                     langNode.setAttribute(QStringLiteral("iso639Id"), lang);
                     langList.appendChild(langNode);
@@ -166,16 +166,16 @@ private Q_SLOTS:
         root.appendChild(layoutList);
 
         QDomElement optionGroupList = doc.createElement(QStringLiteral("optionList"));
-        foreach (const OptionGroupInfo *optionGroupInfo, rules->optionGroupInfos) {
+        for (const OptionGroupInfo *optionGroupInfo : std::as_const(rules->optionGroupInfos)) {
             QDomElement optionGroup = doc.createElement(QStringLiteral("optionGroup"));
             optionGroup.setAttribute(QStringLiteral("name"), optionGroupInfo->name);
             optionGroup.setAttribute(QStringLiteral("description"), optionGroupInfo->description);
             optionGroup.setAttribute(QStringLiteral("exclusive"), optionGroupInfo->exclusive);
 
-            foreach (const OptionInfo *optionGroupInfo, optionGroupInfo->optionInfos) {
+            for (const OptionInfo *optionInfo : optionGroupInfo->optionInfos) {
                 QDomElement option = doc.createElement(QStringLiteral("option"));
-                option.setAttribute(QStringLiteral("name"), optionGroupInfo->name);
-                option.setAttribute(QStringLiteral("description"), optionGroupInfo->description);
+                option.setAttribute(QStringLiteral("name"), optionInfo->name);
+                option.setAttribute(QStringLiteral("description"), optionInfo->description);
                 optionGroup.appendChild(option);
             }
 
@@ -206,12 +206,12 @@ private Q_SLOTS:
         Rules::readRules(rules11, QStringLiteral("config/base.1.1.xml"), false);
         QCOMPARE(rules11->version, QString("1.1"));
 
-        foreach (const LayoutInfo *layoutInfo, rules11->layoutInfos) {
+        for (const LayoutInfo *layoutInfo : std::as_const(rules11->layoutInfos)) {
             QVERIFY(layoutInfo != nullptr);
             QVERIFY(!layoutInfo->name.isEmpty());
             QVERIFY(!layoutInfo->description.isEmpty());
 
-            foreach (const VariantInfo *variantInfo, layoutInfo->variantInfos) {
+            for (const VariantInfo *variantInfo : layoutInfo->variantInfos) {
                 QVERIFY(variantInfo != nullptr);
                 QVERIFY(!variantInfo->name.isEmpty());
                 QVERIFY(!variantInfo->description.isEmpty());
