@@ -18,6 +18,8 @@
 #include <kglobalaccel_component_interface.h>
 #include <kglobalaccel_interface.h>
 
+#include <kglobalaccel_version.h>
+
 #include "kcmkeys_debug.h"
 
 static QStringList buildActionId(const QString &componentUnique, const QString &componentFriendly, const QString &actionUnique, const QString &actionFriendly)
@@ -170,13 +172,17 @@ void GlobalAccelModel::save()
                 const QStringList actionId = buildActionId(it->id, it->displayName, action.id, action.displayName);
                 // TODO: pass action.activeShortcuts to m_globalAccelInterface->setForeignShortcut() as a QSet<QKeySequence>
                 // or QList<QKeySequence>?
-                QList<int> keys;
+                QList<QKeySequence> keys;
                 keys.reserve(action.activeShortcuts.size());
                 for (const QKeySequence &key : qAsConst(action.activeShortcuts)) {
-                    keys.append(key[0]);
+                    keys.append(key);
                 }
                 qCDebug(KCMKEYS) << "Saving" << actionId << action.activeShortcuts << keys;
+#if KGLOBALACCEL_VERSION >= QT_VERSION_CHECK(5, 90, 0)
+                auto reply = m_globalAccelInterface->setForeignShortcutKeys(actionId, keys);
+#else
                 auto reply = m_globalAccelInterface->setForeignShortcut(actionId, keys);
+#endif
                 reply.waitForFinished();
                 if (!reply.isValid()) {
                     qCCritical(KCMKEYS) << "Error while saving";
