@@ -15,7 +15,7 @@
 #include <KLocalizedString>
 #include <KNS3/Button>
 #include <KPluginFactory>
-#include <KPluginSelector>
+#include <KPluginWidget>
 #include <KRunner/RunnerManager>
 #include <QDebug>
 #include <QStandardPaths>
@@ -36,7 +36,7 @@
 #include <QToolButton>
 #include <QVBoxLayout>
 
-K_PLUGIN_FACTORY(SearchConfigModuleFactory, registerPlugin<SearchConfigModule>(); registerPlugin<KRunnerData>();)
+K_PLUGIN_FACTORY_WITH_JSON(SearchConfigModuleFactory, "kcm_plasmasearch.json", registerPlugin<SearchConfigModule>(); registerPlugin<KRunnerData>();)
 
 SearchConfigModule::SearchConfigModule(QWidget *parent, const QVariantList &args)
     : KCModule(parent, args)
@@ -44,7 +44,7 @@ SearchConfigModule::SearchConfigModule(QWidget *parent, const QVariantList &args
     , m_settings(new KRunnerSettings(this))
 {
     KAboutData *about = new KAboutData(QStringLiteral("kcm_search"),
-                                       i18nc("kcm name for About dialog", "Configure Search Bar"),
+                                       i18nc("kcm name for About dialog", "Configure search settings"),
                                        QStringLiteral("0.1"),
                                        QString(),
                                        KAboutLicense::LGPL);
@@ -65,7 +65,7 @@ SearchConfigModule::SearchConfigModule(QWidget *parent, const QVariantList &args
     QHBoxLayout *headerLayout = new QHBoxLayout;
     layout->addLayout(headerLayout);
 
-    QLabel *label = new QLabel(i18n("Enable or disable plugins (used in KRunner and Application Launcher)"));
+    QLabel *label = new QLabel(i18n("Enable or disable plugins (used in KRunner, Application Launcher, and the Overview effect)"));
 
     m_clearHistoryButton = new QToolButton(this);
     m_clearHistoryButton->setIcon(
@@ -85,12 +85,12 @@ SearchConfigModule::SearchConfigModule(QWidget *parent, const QVariantList &args
     connect(m_freeFloating, &QRadioButton::toggled, this, &SearchConfigModule::updateUnmanagedState);
 
     QFormLayout *positionLayout = new QFormLayout;
-    positionLayout->addRow(i18n("Position on screen:"), m_topPositioning);
+    positionLayout->addRow(i18n("KRunner position:"), m_topPositioning);
     positionLayout->addRow(QString(), m_freeFloating);
     m_enableHistory = new QCheckBox(i18n("Enable"), this);
     m_enableHistory->setObjectName("kcfg_historyEnabled");
     positionLayout->addItem(new QSpacerItem(0, 0));
-    positionLayout->addRow(i18n("History:"), m_enableHistory);
+    positionLayout->addRow(i18n("KRunner history:"), m_enableHistory);
     connect(m_enableHistory, &QCheckBox::toggled, m_clearHistoryButton, &QPushButton::setEnabled);
     m_retainPriorSearch = new QCheckBox(i18n("Retain previous search"), this);
     m_retainPriorSearch->setObjectName("kcfg_retainPriorSearch");
@@ -112,16 +112,18 @@ SearchConfigModule::SearchConfigModule(QWidget *parent, const QVariantList &args
     headerLayout->addWidget(label);
     headerLayout->addStretch();
 
-    m_pluginSelector = new KPluginSelector(this);
-    connect(m_pluginSelector, &KPluginSelector::changed, this, &SearchConfigModule::updateUnmanagedState);
+    m_pluginSelector = new KPluginWidget(this);
+    connect(m_pluginSelector, &KPluginWidget::changed, this, &SearchConfigModule::updateUnmanagedState);
 
     qDBusRegisterMetaType<QByteArrayList>();
     qDBusRegisterMetaType<QHash<QString, QByteArrayList>>();
     // This will trigger the reloadConfiguration method for the runner
-    connect(m_pluginSelector, &KPluginSelector::configCommitted, this, [](const QByteArray &componentName) {
+    connect(m_pluginSelector, &KPluginWidget::pluginConfigSaved, this, [](const QString &componentName) {
         QDBusMessage message =
             QDBusMessage::createSignal(QStringLiteral("/krunnerrc"), QStringLiteral("org.kde.kconfig.notify"), QStringLiteral("ConfigChanged"));
-        const QHash<QString, QByteArrayList> changes = {{QStringLiteral("Runners"), {componentName}}};
+        const QHash<QString, QByteArrayList> changes = {
+            {QStringLiteral("Runners"), {componentName.toLocal8Bit()}},
+        };
         message.setArguments({QVariant::fromValue(changes)});
         QDBusConnection::sessionBus().send(message);
     });
@@ -134,12 +136,8 @@ SearchConfigModule::SearchConfigModule(QWidget *parent, const QVariantList &args
     KNS3::Button *downloadButton = new KNS3::Button(i18n("Get New Plugins…"), QStringLiteral("krunner.knsrc"), this);
     connect(downloadButton, &KNS3::Button::dialogFinished, this, [this](const KNS3::Entry::List &changedEntries) {
         if (!changedEntries.isEmpty()) {
-            m_pluginSelector->clearPlugins();
-            m_pluginSelector->addPlugins(KPluginInfo::fromMetaData(Plasma::RunnerManager::runnerMetaDataList()),
-                                         KPluginSelector::ReadConfigFile,
-                                         i18n("Available Plugins"),
-                                         QString(),
-                                         m_config);
+            m_pluginSelector->clear();
+            m_pluginSelector->addPlugins(Plasma::RunnerManager::runnerMetaDataList(), i18n("Available Plugins"));
         }
     });
     downloadLayout->addStretch();
@@ -147,12 +145,13 @@ SearchConfigModule::SearchConfigModule(QWidget *parent, const QVariantList &args
     layout->addLayout(downloadLayout);
 
     connect(this, &SearchConfigModule::defaultsIndicatorsVisibleChanged, this, &SearchConfigModule::updateUnmanagedState);
-    connect(this, &SearchConfigModule::defaultsIndicatorsVisibleChanged, m_pluginSelector, &KPluginSelector::setDefaultsIndicatorsVisible);
+    connect(this, &SearchConfigModule::defaultsIndicatorsVisibleChanged, m_pluginSelector, &KPluginWidget::setDefaultsIndicatorsVisible);
     addConfig(m_settings, this);
 }
 
 void SearchConfigModule::load()
 {
+    m_pluginSelector->clear();
     KCModule::load();
 
     m_topPositioning->setChecked(!m_settings->freeFloating());
@@ -163,16 +162,8 @@ void SearchConfigModule::load()
     // Set focus on the pluginselector to pass focus to search bar.
     m_pluginSelector->setFocus(Qt::OtherFocusReason);
 
-    QT_WARNING_PUSH
-    QT_WARNING_DISABLE_CLANG("-Wdeprecated-declarations")
-    QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")
-    m_pluginSelector->addPlugins(KPluginInfo::fromMetaData(Plasma::RunnerManager::runnerMetaDataList()),
-                                 KPluginSelector::ReadConfigFile,
-                                 i18n("Available Plugins"),
-                                 QString(),
-                                 m_config);
-    QT_WARNING_POP
-    m_pluginSelector->load();
+    m_pluginSelector->addPlugins(Plasma::RunnerManager::runnerMetaDataList(), i18n("Available Plugins"));
+    m_pluginSelector->setConfig(m_config->group("Plugins"));
 
     if (!m_pluginID.isEmpty()) {
         m_pluginSelector->showConfiguration(m_pluginID);
