@@ -1,20 +1,8 @@
 /*
- * Copyright 2017 Roman Gilg <subdiff@gmail.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2017 Roman Gilg <subdiff@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef TOUCHPADCONFIGLIBINPUT_H
 #define TOUCHPADCONFIGLIBINPUT_H
@@ -24,7 +12,6 @@
 class TouchpadBackend;
 class QHideEvent;
 class QQuickWidget;
-class KMessageWidget;
 
 class TouchpadConfigLibinput : public TouchpadConfigPlugin
 {
@@ -47,6 +34,9 @@ public:
     {
     }
 
+Q_SIGNALS:
+    void showMessage(const QString message, int type = 3 /*Kirigami.MessageType.Error*/);
+
 private Q_SLOTS:
     void onChange();
     void onTouchpadAdded(bool success);
@@ -56,7 +46,6 @@ private:
     void hideErrorMessage();
 
     QQuickWidget *m_view;
-    KMessageWidget *m_errorMessage;
 
     bool m_initError;
 };
