@@ -1,31 +1,21 @@
 /*
- * Copyright (C) 2013 Alexander Mezin <mezin.alexander@gmail.com>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2013 Alexander Mezin <mezin.alexander@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kded.h"
 
+#include <KPluginFactory>
 #include <KLocalizedString>
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
 #include <QDBusMessage>
 #include <QDebug>
 
-#include "kdedactions.h"
-#include "plugins.h"
+#include "actions.h"
+
+K_PLUGIN_CLASS_WITH_JSON(TouchpadDisabler, "kded_touchpad.json")
 
 bool TouchpadDisabler::workingTouchpadFound() const
 {
@@ -257,8 +247,6 @@ void TouchpadDisabler::lateInit()
     mousePlugged();
 }
 
-void touchpadApplySavedConfig();
-
 void TouchpadDisabler::handleReset()
 {
     updateCurrentState();
@@ -298,3 +286,5 @@ void TouchpadDisabler::showOsd()
 
     QDBusConnection::sessionBus().asyncCall(msg);
 }
+
+#include "kded.moc"
