@@ -34,6 +34,12 @@ public:
         TypeRole,
     };
 
+    enum {
+        RowAll,
+        RowAttached,
+        RowDetached,
+    };
+
     Qt::ItemFlags flags(const QModelIndex &index) const override;
     QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
     QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
@@ -48,6 +54,9 @@ public:
 
     void setAutomaticMountOnLogin(bool automaticLogin);
     void setAutomaticMountOnPlugin(bool automaticAttached);
+    void setAutomaticUnknown(bool automaticUnknown);
+
+    void updateCheckedColumns(int column = -1);
 
 public Q_SLOTS:
     void forgetDevice(const QString &udi);
@@ -62,11 +71,7 @@ private:
 
     QList<QString> m_attached;
     QList<QString> m_disconnected;
-    QHash<QString, bool> m_loginForced;
-    QHash<QString, bool> m_attachedForced;
-    bool m_automaticLogin;
-    bool m_automaticAttached;
-    AutomounterSettings *m_settings;
+    AutomounterSettings *const m_settings;
 };
 
 #endif
